---
layout: doc
title: Attributes
categories: hints
permalink: /hints/attributes/
---

You can use these HTML attributes to manage or alter hint elements.

 - `data-hint`: The tooltip text of hint
 - `data-hintposition`: Optionally define the position of hint. Options: `top-middle`, `top-left`, `top-right`, `bottom-left`, `bottom-right`, `bottom-middle`, `middle-left`, `middle-right`, `middle-middle`. Default: `top-middle`
